static const uint8_t unicode_rangetab[][2]={
	{0x000a & 0xFF, 0x000a & 0xFF},
	{0x000b & 0xFF, 0x000c & 0xFF},
	{0x000d & 0xFF, 0x000d & 0xFF},
	{0x0020 & 0xFF, 0x0020 & 0xFF},
	{0x0022 & 0xFF, 0x0022 & 0xFF},
	{0x0027 & 0xFF, 0x0027 & 0xFF},
	{0x002c & 0xFF, 0x002c & 0xFF},
	{0x002e & 0xFF, 0x002e & 0xFF},
	{0x0030 & 0xFF, 0x0039 & 0xFF},
	{0x003a & 0xFF, 0x003a & 0xFF},
	{0x003b & 0xFF, 0x003b & 0xFF},
	{0x0041 & 0xFF, 0x005a & 0xFF},
	{0x005f & 0xFF, 0x005f & 0xFF},
	{0x0061 & 0xFF, 0x007a & 0xFF},
	{0x0085 & 0xFF, 0x0085 & 0xFF},
	{0x00aa & 0xFF, 0x00aa & 0xFF},
	{0x00ad & 0xFF, 0x00ad & 0xFF},
	{0x00b5 & 0xFF, 0x00b5 & 0xFF},
	{0x00b7 & 0xFF, 0x00b7 & 0xFF},
	{0x00ba & 0xFF, 0x00ba & 0xFF},
	{0x00c0 & 0xFF, 0x00d6 & 0xFF},
	{0x00d8 & 0xFF, 0x00f6 & 0xFF},
	{0x00f8 & 0xFF, 0x00ff & 0xFF},
	{0x0100 & 0xFF, 0x01ff & 0xFF},
	{0x0200 & 0xFF, 0x02d7 & 0xFF},
	{0x02de & 0xFF, 0x02ff & 0xFF},
	{0x0300 & 0xFF, 0x036f & 0xFF},
	{0x0370 & 0xFF, 0x0374 & 0xFF},
	{0x0376 & 0xFF, 0x0377 & 0xFF},
	{0x037a & 0xFF, 0x037d & 0xFF},
	{0x037e & 0xFF, 0x037e & 0xFF},
	{0x037f & 0xFF, 0x037f & 0xFF},
	{0x0386 & 0xFF, 0x0386 & 0xFF},
	{0x0387 & 0xFF, 0x0387 & 0xFF},
	{0x0388 & 0xFF, 0x038a & 0xFF},
	{0x038c & 0xFF, 0x038c & 0xFF},
	{0x038e & 0xFF, 0x03a1 & 0xFF},
	{0x03a3 & 0xFF, 0x03f5 & 0xFF},
	{0x03f7 & 0xFF, 0x03ff & 0xFF},
	{0x0400 & 0xFF, 0x0481 & 0xFF},
	{0x0483 & 0xFF, 0x0489 & 0xFF},
	{0x048a & 0xFF, 0x04ff & 0xFF},
	{0x0500 & 0xFF, 0x052f & 0xFF},
	{0x0531 & 0xFF, 0x0556 & 0xFF},
	{0x0559 & 0xFF, 0x055c & 0xFF},
	{0x055e & 0xFF, 0x055e & 0xFF},
	{0x055f & 0xFF, 0x055f & 0xFF},
	{0x0560 & 0xFF, 0x0588 & 0xFF},
	{0x0589 & 0xFF, 0x0589 & 0xFF},
	{0x058a & 0xFF, 0x058a & 0xFF},
	{0x0591 & 0xFF, 0x05bd & 0xFF},
	{0x05bf & 0xFF, 0x05bf & 0xFF},
	{0x05c1 & 0xFF, 0x05c2 & 0xFF},
	{0x05c4 & 0xFF, 0x05c5 & 0xFF},
	{0x05c7 & 0xFF, 0x05c7 & 0xFF},
	{0x05d0 & 0xFF, 0x05ea & 0xFF},
	{0x05ef & 0xFF, 0x05f2 & 0xFF},
	{0x05f3 & 0xFF, 0x05f3 & 0xFF},
	{0x05f4 & 0xFF, 0x05f4 & 0xFF},
	{0x0600 & 0xFF, 0x0605 & 0xFF},
	{0x060c & 0xFF, 0x060d & 0xFF},
	{0x0610 & 0xFF, 0x061a & 0xFF},
	{0x061c & 0xFF, 0x061c & 0xFF},
	{0x0620 & 0xFF, 0x064a & 0xFF},
	{0x064b & 0xFF, 0x065f & 0xFF},
	{0x0660 & 0xFF, 0x0669 & 0xFF},
	{0x066b & 0xFF, 0x066b & 0xFF},
	{0x066c & 0xFF, 0x066c & 0xFF},
	{0x066e & 0xFF, 0x066f & 0xFF},
	{0x0670 & 0xFF, 0x0670 & 0xFF},
	{0x0671 & 0xFF, 0x06d3 & 0xFF},
	{0x06d5 & 0xFF, 0x06d5 & 0xFF},
	{0x06d6 & 0xFF, 0x06dc & 0xFF},
	{0x06dd & 0xFF, 0x06dd & 0xFF},
	{0x06df & 0xFF, 0x06e4 & 0xFF},
	{0x06e5 & 0xFF, 0x06e6 & 0xFF},
	{0x06e7 & 0xFF, 0x06e8 & 0xFF},
	{0x06ea & 0xFF, 0x06ed & 0xFF},
	{0x06ee & 0xFF, 0x06ef & 0xFF},
	{0x06f0 & 0xFF, 0x06f9 & 0xFF},
	{0x06fa & 0xFF, 0x06fc & 0xFF},
	{0x06ff & 0xFF, 0x06ff & 0xFF},
	{0x070f & 0xFF, 0x0710 & 0xFF},
	{0x0711 & 0xFF, 0x0711 & 0xFF},
	{0x0712 & 0xFF, 0x072f & 0xFF},
	{0x0730 & 0xFF, 0x074a & 0xFF},
	{0x074d & 0xFF, 0x07a5 & 0xFF},
	{0x07a6 & 0xFF, 0x07b0 & 0xFF},
	{0x07b1 & 0xFF, 0x07b1 & 0xFF},
	{0x07c0 & 0xFF, 0x07c9 & 0xFF},
	{0x07ca & 0xFF, 0x07ea & 0xFF},
	{0x07eb & 0xFF, 0x07f3 & 0xFF},
	{0x07f4 & 0xFF, 0x07f5 & 0xFF},
	{0x07f8 & 0xFF, 0x07f8 & 0xFF},
	{0x07fa & 0xFF, 0x07fa & 0xFF},
	{0x07fd & 0xFF, 0x07fd & 0xFF},
	{0x0800 & 0xFF, 0x0815 & 0xFF},
	{0x0816 & 0xFF, 0x0819 & 0xFF},
	{0x081a & 0xFF, 0x081a & 0xFF},
	{0x081b & 0xFF, 0x0823 & 0xFF},
	{0x0824 & 0xFF, 0x0824 & 0xFF},
	{0x0825 & 0xFF, 0x0827 & 0xFF},
	{0x0828 & 0xFF, 0x0828 & 0xFF},
	{0x0829 & 0xFF, 0x082d & 0xFF},
	{0x0840 & 0xFF, 0x0858 & 0xFF},
	{0x0859 & 0xFF, 0x085b & 0xFF},
	{0x0860 & 0xFF, 0x086a & 0xFF},
	{0x0870 & 0xFF, 0x0887 & 0xFF},
	{0x0889 & 0xFF, 0x088e & 0xFF},
	{0x0890 & 0xFF, 0x0891 & 0xFF},
	{0x0897 & 0xFF, 0x089f & 0xFF},
	{0x08a0 & 0xFF, 0x08c9 & 0xFF},
	{0x08ca & 0xFF, 0x08e1 & 0xFF},
	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
	{0x08e3 & 0xFF, 0x08ff & 0xFF},
	{0x0900 & 0xFF, 0x0903 & 0xFF},
	{0x0904 & 0xFF, 0x0939 & 0xFF},
	{0x093a & 0xFF, 0x093c & 0xFF},
	{0x093d & 0xFF, 0x093d & 0xFF},
	{0x093e & 0xFF, 0x094f & 0xFF},
	{0x0950 & 0xFF, 0x0950 & 0xFF},
	{0x0951 & 0xFF, 0x0957 & 0xFF},
	{0x0958 & 0xFF, 0x0961 & 0xFF},
	{0x0962 & 0xFF, 0x0963 & 0xFF},
	{0x0966 & 0xFF, 0x096f & 0xFF},
	{0x0971 & 0xFF, 0x0980 & 0xFF},
	{0x0981 & 0xFF, 0x0983 & 0xFF},
	{0x0985 & 0xFF, 0x098c & 0xFF},
	{0x098f & 0xFF, 0x0990 & 0xFF},
	{0x0993 & 0xFF, 0x09a8 & 0xFF},
	{0x09aa & 0xFF, 0x09b0 & 0xFF},
	{0x09b2 & 0xFF, 0x09b2 & 0xFF},
	{0x09b6 & 0xFF, 0x09b9 & 0xFF},
	{0x09bc & 0xFF, 0x09bc & 0xFF},
	{0x09bd & 0xFF, 0x09bd & 0xFF},
	{0x09be & 0xFF, 0x09c4 & 0xFF},
	{0x09c7 & 0xFF, 0x09c8 & 0xFF},
	{0x09cb & 0xFF, 0x09cd & 0xFF},
	{0x09ce & 0xFF, 0x09ce & 0xFF},
	{0x09d7 & 0xFF, 0x09d7 & 0xFF},
	{0x09dc & 0xFF, 0x09dd & 0xFF},
	{0x09df & 0xFF, 0x09e1 & 0xFF},
	{0x09e2 & 0xFF, 0x09e3 & 0xFF},
	{0x09e6 & 0xFF, 0x09ef & 0xFF},
	{0x09f0 & 0xFF, 0x09f1 & 0xFF},
	{0x09fc & 0xFF, 0x09fc & 0xFF},
	{0x09fe & 0xFF, 0x09fe & 0xFF},
	{0x0a01 & 0xFF, 0x0a03 & 0xFF},
	{0x0a05 & 0xFF, 0x0a0a & 0xFF},
	{0x0a0f & 0xFF, 0x0a10 & 0xFF},
	{0x0a13 & 0xFF, 0x0a28 & 0xFF},
	{0x0a2a & 0xFF, 0x0a30 & 0xFF},
	{0x0a32 & 0xFF, 0x0a33 & 0xFF},
	{0x0a35 & 0xFF, 0x0a36 & 0xFF},
	{0x0a38 & 0xFF, 0x0a39 & 0xFF},
	{0x0a3c & 0xFF, 0x0a3c & 0xFF},
	{0x0a3e & 0xFF, 0x0a42 & 0xFF},
	{0x0a47 & 0xFF, 0x0a48 & 0xFF},
	{0x0a4b & 0xFF, 0x0a4d & 0xFF},
	{0x0a51 & 0xFF, 0x0a51 & 0xFF},
	{0x0a59 & 0xFF, 0x0a5c & 0xFF},
	{0x0a5e & 0xFF, 0x0a5e & 0xFF},
	{0x0a66 & 0xFF, 0x0a6f & 0xFF},
	{0x0a70 & 0xFF, 0x0a71 & 0xFF},
	{0x0a72 & 0xFF, 0x0a74 & 0xFF},
	{0x0a75 & 0xFF, 0x0a75 & 0xFF},
	{0x0a81 & 0xFF, 0x0a83 & 0xFF},
	{0x0a85 & 0xFF, 0x0a8d & 0xFF},
	{0x0a8f & 0xFF, 0x0a91 & 0xFF},
	{0x0a93 & 0xFF, 0x0aa8 & 0xFF},
	{0x0aaa & 0xFF, 0x0ab0 & 0xFF},
	{0x0ab2 & 0xFF, 0x0ab3 & 0xFF},
	{0x0ab5 & 0xFF, 0x0ab9 & 0xFF},
	{0x0abc & 0xFF, 0x0abc & 0xFF},
	{0x0abd & 0xFF, 0x0abd & 0xFF},
	{0x0abe & 0xFF, 0x0ac5 & 0xFF},
	{0x0ac7 & 0xFF, 0x0ac9 & 0xFF},
	{0x0acb & 0xFF, 0x0acd & 0xFF},
	{0x0ad0 & 0xFF, 0x0ad0 & 0xFF},
	{0x0ae0 & 0xFF, 0x0ae1 & 0xFF},
	{0x0ae2 & 0xFF, 0x0ae3 & 0xFF},
	{0x0ae6 & 0xFF, 0x0aef & 0xFF},
	{0x0af9 & 0xFF, 0x0af9 & 0xFF},
	{0x0afa & 0xFF, 0x0aff & 0xFF},
	{0x0b01 & 0xFF, 0x0b03 & 0xFF},
	{0x0b05 & 0xFF, 0x0b0c & 0xFF},
	{0x0b0f & 0xFF, 0x0b10 & 0xFF},
	{0x0b13 & 0xFF, 0x0b28 & 0xFF},
	{0x0b2a & 0xFF, 0x0b30 & 0xFF},
	{0x0b32 & 0xFF, 0x0b33 & 0xFF},
	{0x0b35 & 0xFF, 0x0b39 & 0xFF},
	{0x0b3c & 0xFF, 0x0b3c & 0xFF},
	{0x0b3d & 0xFF, 0x0b3d & 0xFF},
	{0x0b3e & 0xFF, 0x0b44 & 0xFF},
	{0x0b47 & 0xFF, 0x0b48 & 0xFF},
	{0x0b4b & 0xFF, 0x0b4d & 0xFF},
	{0x0b55 & 0xFF, 0x0b57 & 0xFF},
	{0x0b5c & 0xFF, 0x0b5d & 0xFF},
	{0x0b5f & 0xFF, 0x0b61 & 0xFF},
	{0x0b62 & 0xFF, 0x0b63 & 0xFF},
	{0x0b66 & 0xFF, 0x0b6f & 0xFF},
	{0x0b71 & 0xFF, 0x0b71 & 0xFF},
	{0x0b82 & 0xFF, 0x0b82 & 0xFF},
	{0x0b83 & 0xFF, 0x0b83 & 0xFF},
	{0x0b85 & 0xFF, 0x0b8a & 0xFF},
	{0x0b8e & 0xFF, 0x0b90 & 0xFF},
	{0x0b92 & 0xFF, 0x0b95 & 0xFF},
	{0x0b99 & 0xFF, 0x0b9a & 0xFF},
	{0x0b9c & 0xFF, 0x0b9c & 0xFF},
	{0x0b9e & 0xFF, 0x0b9f & 0xFF},
	{0x0ba3 & 0xFF, 0x0ba4 & 0xFF},
	{0x0ba8 & 0xFF, 0x0baa & 0xFF},
	{0x0bae & 0xFF, 0x0bb9 & 0xFF},
	{0x0bbe & 0xFF, 0x0bc2 & 0xFF},
	{0x0bc6 & 0xFF, 0x0bc8 & 0xFF},
	{0x0bca & 0xFF, 0x0bcd & 0xFF},
	{0x0bd0 & 0xFF, 0x0bd0 & 0xFF},
	{0x0bd7 & 0xFF, 0x0bd7 & 0xFF},
	{0x0be6 & 0xFF, 0x0bef & 0xFF},
	{0x0c00 & 0xFF, 0x0c04 & 0xFF},
	{0x0c05 & 0xFF, 0x0c0c & 0xFF},
	{0x0c0e & 0xFF, 0x0c10 & 0xFF},
	{0x0c12 & 0xFF, 0x0c28 & 0xFF},
	{0x0c2a & 0xFF, 0x0c39 & 0xFF},
	{0x0c3c & 0xFF, 0x0c3c & 0xFF},
	{0x0c3d & 0xFF, 0x0c3d & 0xFF},
	{0x0c3e & 0xFF, 0x0c44 & 0xFF},
	{0x0c46 & 0xFF, 0x0c48 & 0xFF},
	{0x0c4a & 0xFF, 0x0c4d & 0xFF},
	{0x0c55 & 0xFF, 0x0c56 & 0xFF},
	{0x0c58 & 0xFF, 0x0c5a & 0xFF},
	{0x0c5d & 0xFF, 0x0c5d & 0xFF},
	{0x0c60 & 0xFF, 0x0c61 & 0xFF},
	{0x0c62 & 0xFF, 0x0c63 & 0xFF},
	{0x0c66 & 0xFF, 0x0c6f & 0xFF},
	{0x0c80 & 0xFF, 0x0c80 & 0xFF},
	{0x0c81 & 0xFF, 0x0c83 & 0xFF},
	{0x0c85 & 0xFF, 0x0c8c & 0xFF},
	{0x0c8e & 0xFF, 0x0c90 & 0xFF},
	{0x0c92 & 0xFF, 0x0ca8 & 0xFF},
	{0x0caa & 0xFF, 0x0cb3 & 0xFF},
	{0x0cb5 & 0xFF, 0x0cb9 & 0xFF},
	{0x0cbc & 0xFF, 0x0cbc & 0xFF},
	{0x0cbd & 0xFF, 0x0cbd & 0xFF},
	{0x0cbe & 0xFF, 0x0cc4 & 0xFF},
	{0x0cc6 & 0xFF, 0x0cc8 & 0xFF},
	{0x0cca & 0xFF, 0x0ccd & 0xFF},
	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
	{0x0cdd & 0xFF, 0x0cde & 0xFF},
	{0x0ce0 & 0xFF, 0x0ce1 & 0xFF},
	{0x0ce2 & 0xFF, 0x0ce3 & 0xFF},
	{0x0ce6 & 0xFF, 0x0cef & 0xFF},
	{0x0cf1 & 0xFF, 0x0cf2 & 0xFF},
	{0x0cf3 & 0xFF, 0x0cf3 & 0xFF},
	{0x0d00 & 0xFF, 0x0d03 & 0xFF},
	{0x0d04 & 0xFF, 0x0d0c & 0xFF},
	{0x0d0e & 0xFF, 0x0d10 & 0xFF},
	{0x0d12 & 0xFF, 0x0d3a & 0xFF},
	{0x0d3b & 0xFF, 0x0d3c & 0xFF},
	{0x0d3d & 0xFF, 0x0d3d & 0xFF},
	{0x0d3e & 0xFF, 0x0d44 & 0xFF},
	{0x0d46 & 0xFF, 0x0d48 & 0xFF},
	{0x0d4a & 0xFF, 0x0d4d & 0xFF},
	{0x0d4e & 0xFF, 0x0d4e & 0xFF},
	{0x0d54 & 0xFF, 0x0d56 & 0xFF},
	{0x0d57 & 0xFF, 0x0d57 & 0xFF},
	{0x0d5f & 0xFF, 0x0d61 & 0xFF},
	{0x0d62 & 0xFF, 0x0d63 & 0xFF},
	{0x0d66 & 0xFF, 0x0d6f & 0xFF},
	{0x0d7a & 0xFF, 0x0d7f & 0xFF},
	{0x0d81 & 0xFF, 0x0d83 & 0xFF},
	{0x0d85 & 0xFF, 0x0d96 & 0xFF},
	{0x0d9a & 0xFF, 0x0db1 & 0xFF},
	{0x0db3 & 0xFF, 0x0dbb & 0xFF},
	{0x0dbd & 0xFF, 0x0dbd & 0xFF},
	{0x0dc0 & 0xFF, 0x0dc6 & 0xFF},
	{0x0dca & 0xFF, 0x0dca & 0xFF},
	{0x0dcf & 0xFF, 0x0dd4 & 0xFF},
	{0x0dd6 & 0xFF, 0x0dd6 & 0xFF},
	{0x0dd8 & 0xFF, 0x0ddf & 0xFF},
	{0x0de6 & 0xFF, 0x0def & 0xFF},
	{0x0df2 & 0xFF, 0x0df3 & 0xFF},
	{0x0e31 & 0xFF, 0x0e31 & 0xFF},
	{0x0e34 & 0xFF, 0x0e3a & 0xFF},
	{0x0e47 & 0xFF, 0x0e4e & 0xFF},
	{0x0e50 & 0xFF, 0x0e59 & 0xFF},
	{0x0eb1 & 0xFF, 0x0eb1 & 0xFF},
	{0x0eb4 & 0xFF, 0x0ebc & 0xFF},
	{0x0ec8 & 0xFF, 0x0ece & 0xFF},
	{0x0ed0 & 0xFF, 0x0ed9 & 0xFF},
	{0x0f00 & 0xFF, 0x0f00 & 0xFF},
	{0x0f18 & 0xFF, 0x0f19 & 0xFF},
	{0x0f20 & 0xFF, 0x0f29 & 0xFF},
	{0x0f35 & 0xFF, 0x0f35 & 0xFF},
	{0x0f37 & 0xFF, 0x0f37 & 0xFF},
	{0x0f39 & 0xFF, 0x0f39 & 0xFF},
	{0x0f3e & 0xFF, 0x0f3f & 0xFF},
	{0x0f40 & 0xFF, 0x0f47 & 0xFF},
	{0x0f49 & 0xFF, 0x0f6c & 0xFF},
	{0x0f71 & 0xFF, 0x0f84 & 0xFF},
	{0x0f86 & 0xFF, 0x0f87 & 0xFF},
	{0x0f88 & 0xFF, 0x0f8c & 0xFF},
	{0x0f8d & 0xFF, 0x0f97 & 0xFF},
	{0x0f99 & 0xFF, 0x0fbc & 0xFF},
	{0x0fc6 & 0xFF, 0x0fc6 & 0xFF},
	{0x102b & 0xFF, 0x103e & 0xFF},
	{0x1040 & 0xFF, 0x1049 & 0xFF},
	{0x1056 & 0xFF, 0x1059 & 0xFF},
	{0x105e & 0xFF, 0x1060 & 0xFF},
	{0x1062 & 0xFF, 0x1064 & 0xFF},
	{0x1067 & 0xFF, 0x106d & 0xFF},
	{0x1071 & 0xFF, 0x1074 & 0xFF},
	{0x1082 & 0xFF, 0x108d & 0xFF},
	{0x108f & 0xFF, 0x108f & 0xFF},
	{0x1090 & 0xFF, 0x1099 & 0xFF},
	{0x109a & 0xFF, 0x109d & 0xFF},
	{0x10a0 & 0xFF, 0x10c5 & 0xFF},
	{0x10c7 & 0xFF, 0x10c7 & 0xFF},
	{0x10cd & 0xFF, 0x10cd & 0xFF},
	{0x10d0 & 0xFF, 0x10fa & 0xFF},
	{0x10fc & 0xFF, 0x10ff & 0xFF},
	{0x1100 & 0xFF, 0x11ff & 0xFF},
	{0x1200 & 0xFF, 0x1248 & 0xFF},
	{0x124a & 0xFF, 0x124d & 0xFF},
	{0x1250 & 0xFF, 0x1256 & 0xFF},
	{0x1258 & 0xFF, 0x1258 & 0xFF},
	{0x125a & 0xFF, 0x125d & 0xFF},
	{0x1260 & 0xFF, 0x1288 & 0xFF},
	{0x128a & 0xFF, 0x128d & 0xFF},
	{0x1290 & 0xFF, 0x12b0 & 0xFF},
	{0x12b2 & 0xFF, 0x12b5 & 0xFF},
	{0x12b8 & 0xFF, 0x12be & 0xFF},
	{0x12c0 & 0xFF, 0x12c0 & 0xFF},
	{0x12c2 & 0xFF, 0x12c5 & 0xFF},
	{0x12c8 & 0xFF, 0x12d6 & 0xFF},
	{0x12d8 & 0xFF, 0x12ff & 0xFF},
	{0x1300 & 0xFF, 0x1310 & 0xFF},
	{0x1312 & 0xFF, 0x1315 & 0xFF},
	{0x1318 & 0xFF, 0x135a & 0xFF},
	{0x135d & 0xFF, 0x135f & 0xFF},
	{0x1380 & 0xFF, 0x138f & 0xFF},
	{0x13a0 & 0xFF, 0x13f5 & 0xFF},
	{0x13f8 & 0xFF, 0x13fd & 0xFF},
	{0x1401 & 0xFF, 0x14ff & 0xFF},
	{0x1500 & 0xFF, 0x15ff & 0xFF},
	{0x1600 & 0xFF, 0x166c & 0xFF},
	{0x166f & 0xFF, 0x167f & 0xFF},
	{0x1680 & 0xFF, 0x1680 & 0xFF},
	{0x1681 & 0xFF, 0x169a & 0xFF},
	{0x16a0 & 0xFF, 0x16ea & 0xFF},
	{0x16ee & 0xFF, 0x16f8 & 0xFF},
	{0x1700 & 0xFF, 0x1711 & 0xFF},
	{0x1712 & 0xFF, 0x1715 & 0xFF},
	{0x171f & 0xFF, 0x1731 & 0xFF},
	{0x1732 & 0xFF, 0x1734 & 0xFF},
	{0x1740 & 0xFF, 0x1751 & 0xFF},
	{0x1752 & 0xFF, 0x1753 & 0xFF},
	{0x1760 & 0xFF, 0x176c & 0xFF},
	{0x176e & 0xFF, 0x1770 & 0xFF},
	{0x1772 & 0xFF, 0x1773 & 0xFF},
	{0x17b4 & 0xFF, 0x17d3 & 0xFF},
	{0x17dd & 0xFF, 0x17dd & 0xFF},
	{0x17e0 & 0xFF, 0x17e9 & 0xFF},
	{0x180b & 0xFF, 0x180d & 0xFF},
	{0x180e & 0xFF, 0x180e & 0xFF},
	{0x180f & 0xFF, 0x180f & 0xFF},
	{0x1810 & 0xFF, 0x1819 & 0xFF},
	{0x1820 & 0xFF, 0x1878 & 0xFF},
	{0x1880 & 0xFF, 0x1884 & 0xFF},
	{0x1885 & 0xFF, 0x1886 & 0xFF},
	{0x1887 & 0xFF, 0x18a8 & 0xFF},
	{0x18a9 & 0xFF, 0x18a9 & 0xFF},
	{0x18aa & 0xFF, 0x18aa & 0xFF},
	{0x18b0 & 0xFF, 0x18f5 & 0xFF},
	{0x1900 & 0xFF, 0x191e & 0xFF},
	{0x1920 & 0xFF, 0x192b & 0xFF},
	{0x1930 & 0xFF, 0x193b & 0xFF},
	{0x1946 & 0xFF, 0x194f & 0xFF},
	{0x19d0 & 0xFF, 0x19da & 0xFF},
	{0x1a00 & 0xFF, 0x1a16 & 0xFF},
	{0x1a17 & 0xFF, 0x1a1b & 0xFF},
	{0x1a55 & 0xFF, 0x1a5e & 0xFF},
	{0x1a60 & 0xFF, 0x1a7c & 0xFF},
	{0x1a7f & 0xFF, 0x1a7f & 0xFF},
	{0x1a80 & 0xFF, 0x1a89 & 0xFF},
	{0x1a90 & 0xFF, 0x1a99 & 0xFF},
	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
	{0x1b00 & 0xFF, 0x1b04 & 0xFF},
	{0x1b05 & 0xFF, 0x1b33 & 0xFF},
	{0x1b34 & 0xFF, 0x1b44 & 0xFF},
	{0x1b45 & 0xFF, 0x1b4c & 0xFF},
	{0x1b50 & 0xFF, 0x1b59 & 0xFF},
	{0x1b6b & 0xFF, 0x1b73 & 0xFF},
	{0x1b80 & 0xFF, 0x1b82 & 0xFF},
	{0x1b83 & 0xFF, 0x1ba0 & 0xFF},
	{0x1ba1 & 0xFF, 0x1bad & 0xFF},
	{0x1bae & 0xFF, 0x1baf & 0xFF},
	{0x1bb0 & 0xFF, 0x1bb9 & 0xFF},
	{0x1bba & 0xFF, 0x1be5 & 0xFF},
	{0x1be6 & 0xFF, 0x1bf3 & 0xFF},
	{0x1c00 & 0xFF, 0x1c23 & 0xFF},
	{0x1c24 & 0xFF, 0x1c37 & 0xFF},
	{0x1c40 & 0xFF, 0x1c49 & 0xFF},
	{0x1c4d & 0xFF, 0x1c4f & 0xFF},
	{0x1c50 & 0xFF, 0x1c59 & 0xFF},
	{0x1c5a & 0xFF, 0x1c7d & 0xFF},
	{0x1c80 & 0xFF, 0x1c8a & 0xFF},
	{0x1c90 & 0xFF, 0x1cba & 0xFF},
	{0x1cbd & 0xFF, 0x1cbf & 0xFF},
	{0x1cd0 & 0xFF, 0x1cd2 & 0xFF},
	{0x1cd4 & 0xFF, 0x1ce8 & 0xFF},
	{0x1ce9 & 0xFF, 0x1cec & 0xFF},
	{0x1ced & 0xFF, 0x1ced & 0xFF},
	{0x1cee & 0xFF, 0x1cf3 & 0xFF},
	{0x1cf4 & 0xFF, 0x1cf4 & 0xFF},
	{0x1cf5 & 0xFF, 0x1cf6 & 0xFF},
	{0x1cf7 & 0xFF, 0x1cf9 & 0xFF},
	{0x1cfa & 0xFF, 0x1cfa & 0xFF},
	{0x1d00 & 0xFF, 0x1dbf & 0xFF},
	{0x1dc0 & 0xFF, 0x1dff & 0xFF},
	{0x1e00 & 0xFF, 0x1eff & 0xFF},
	{0x1f00 & 0xFF, 0x1f15 & 0xFF},
	{0x1f18 & 0xFF, 0x1f1d & 0xFF},
	{0x1f20 & 0xFF, 0x1f45 & 0xFF},
	{0x1f48 & 0xFF, 0x1f4d & 0xFF},
	{0x1f50 & 0xFF, 0x1f57 & 0xFF},
	{0x1f59 & 0xFF, 0x1f59 & 0xFF},
	{0x1f5b & 0xFF, 0x1f5b & 0xFF},
	{0x1f5d & 0xFF, 0x1f5d & 0xFF},
	{0x1f5f & 0xFF, 0x1f7d & 0xFF},
	{0x1f80 & 0xFF, 0x1fb4 & 0xFF},
	{0x1fb6 & 0xFF, 0x1fbc & 0xFF},
	{0x1fbe & 0xFF, 0x1fbe & 0xFF},
	{0x1fc2 & 0xFF, 0x1fc4 & 0xFF},
	{0x1fc6 & 0xFF, 0x1fcc & 0xFF},
	{0x1fd0 & 0xFF, 0x1fd3 & 0xFF},
	{0x1fd6 & 0xFF, 0x1fdb & 0xFF},
	{0x1fe0 & 0xFF, 0x1fec & 0xFF},
	{0x1ff2 & 0xFF, 0x1ff4 & 0xFF},
	{0x1ff6 & 0xFF, 0x1ffc & 0xFF},
	{0x2000 & 0xFF, 0x2006 & 0xFF},
	{0x2008 & 0xFF, 0x200a & 0xFF},
	{0x200c & 0xFF, 0x200c & 0xFF},
	{0x200d & 0xFF, 0x200d & 0xFF},
	{0x200e & 0xFF, 0x200f & 0xFF},
	{0x2018 & 0xFF, 0x2019 & 0xFF},
	{0x2024 & 0xFF, 0x2024 & 0xFF},
	{0x2027 & 0xFF, 0x2027 & 0xFF},
	{0x2028 & 0xFF, 0x2029 & 0xFF},
	{0x202a & 0xFF, 0x202e & 0xFF},
	{0x202f & 0xFF, 0x202f & 0xFF},
	{0x203f & 0xFF, 0x2040 & 0xFF},
	{0x2044 & 0xFF, 0x2044 & 0xFF},
	{0x2054 & 0xFF, 0x2054 & 0xFF},
	{0x205f & 0xFF, 0x205f & 0xFF},
	{0x2060 & 0xFF, 0x2064 & 0xFF},
	{0x2066 & 0xFF, 0x206f & 0xFF},
	{0x2071 & 0xFF, 0x2071 & 0xFF},
	{0x207f & 0xFF, 0x207f & 0xFF},
	{0x2090 & 0xFF, 0x209c & 0xFF},
	{0x20d0 & 0xFF, 0x20f0 & 0xFF},
	{0x2102 & 0xFF, 0x2102 & 0xFF},
	{0x2107 & 0xFF, 0x2107 & 0xFF},
	{0x210a & 0xFF, 0x2113 & 0xFF},
	{0x2115 & 0xFF, 0x2115 & 0xFF},
	{0x2119 & 0xFF, 0x211d & 0xFF},
	{0x2124 & 0xFF, 0x2124 & 0xFF},
	{0x2126 & 0xFF, 0x2126 & 0xFF},
	{0x2128 & 0xFF, 0x2128 & 0xFF},
	{0x212a & 0xFF, 0x212d & 0xFF},
	{0x212f & 0xFF, 0x2139 & 0xFF},
	{0x213c & 0xFF, 0x213f & 0xFF},
	{0x2145 & 0xFF, 0x2149 & 0xFF},
	{0x214e & 0xFF, 0x214e & 0xFF},
	{0x2160 & 0xFF, 0x2188 & 0xFF},
	{0x24b6 & 0xFF, 0x24e9 & 0xFF},
	{0x2c00 & 0xFF, 0x2ce4 & 0xFF},
	{0x2ceb & 0xFF, 0x2cee & 0xFF},
	{0x2cef & 0xFF, 0x2cf1 & 0xFF},
	{0x2cf2 & 0xFF, 0x2cf3 & 0xFF},
	{0x2d00 & 0xFF, 0x2d25 & 0xFF},
	{0x2d27 & 0xFF, 0x2d27 & 0xFF},
	{0x2d2d & 0xFF, 0x2d2d & 0xFF},
	{0x2d30 & 0xFF, 0x2d67 & 0xFF},
	{0x2d6f & 0xFF, 0x2d6f & 0xFF},
	{0x2d7f & 0xFF, 0x2d7f & 0xFF},
	{0x2d80 & 0xFF, 0x2d96 & 0xFF},
	{0x2da0 & 0xFF, 0x2da6 & 0xFF},
	{0x2da8 & 0xFF, 0x2dae & 0xFF},
	{0x2db0 & 0xFF, 0x2db6 & 0xFF},
	{0x2db8 & 0xFF, 0x2dbe & 0xFF},
	{0x2dc0 & 0xFF, 0x2dc6 & 0xFF},
	{0x2dc8 & 0xFF, 0x2dce & 0xFF},
	{0x2dd0 & 0xFF, 0x2dd6 & 0xFF},
	{0x2dd8 & 0xFF, 0x2dde & 0xFF},
	{0x2de0 & 0xFF, 0x2dff & 0xFF},
	{0x2e2f & 0xFF, 0x2e2f & 0xFF},
	{0x3000 & 0xFF, 0x3000 & 0xFF},
	{0x3005 & 0xFF, 0x3005 & 0xFF},
	{0x302a & 0xFF, 0x302f & 0xFF},
	{0x3031 & 0xFF, 0x3035 & 0xFF},
	{0x303b & 0xFF, 0x303c & 0xFF},
	{0x3099 & 0xFF, 0x309a & 0xFF},
	{0x309b & 0xFF, 0x309c & 0xFF},
	{0x30a0 & 0xFF, 0x30fa & 0xFF},
	{0x30fc & 0xFF, 0x30ff & 0xFF},
	{0x3105 & 0xFF, 0x312f & 0xFF},
	{0x3131 & 0xFF, 0x318e & 0xFF},
	{0x31a0 & 0xFF, 0x31bf & 0xFF},
	{0x31f0 & 0xFF, 0x31ff & 0xFF},
	{0x32d0 & 0xFF, 0x32fe & 0xFF},
	{0x3300 & 0xFF, 0x3357 & 0xFF},
	{0xa000 & 0xFF, 0xa0ff & 0xFF},
	{0xa100 & 0xFF, 0xa1ff & 0xFF},
	{0xa200 & 0xFF, 0xa2ff & 0xFF},
	{0xa300 & 0xFF, 0xa3ff & 0xFF},
	{0xa400 & 0xFF, 0xa48c & 0xFF},
	{0xa4d0 & 0xFF, 0xa4fd & 0xFF},
	{0xa500 & 0xFF, 0xa5ff & 0xFF},
	{0xa600 & 0xFF, 0xa60c & 0xFF},
	{0xa610 & 0xFF, 0xa61f & 0xFF},
	{0xa620 & 0xFF, 0xa629 & 0xFF},
	{0xa62a & 0xFF, 0xa62b & 0xFF},
	{0xa640 & 0xFF, 0xa66e & 0xFF},
	{0xa66f & 0xFF, 0xa672 & 0xFF},
	{0xa674 & 0xFF, 0xa67d & 0xFF},
	{0xa67f & 0xFF, 0xa69d & 0xFF},
	{0xa69e & 0xFF, 0xa69f & 0xFF},
	{0xa6a0 & 0xFF, 0xa6ef & 0xFF},
	{0xa6f0 & 0xFF, 0xa6f1 & 0xFF},
	{0xa708 & 0xFF, 0xa7cd & 0xFF},
	{0xa7d0 & 0xFF, 0xa7d1 & 0xFF},
	{0xa7d3 & 0xFF, 0xa7d3 & 0xFF},
	{0xa7d5 & 0xFF, 0xa7dc & 0xFF},
	{0xa7f2 & 0xFF, 0xa7ff & 0xFF},
	{0xa800 & 0xFF, 0xa801 & 0xFF},
	{0xa802 & 0xFF, 0xa802 & 0xFF},
	{0xa803 & 0xFF, 0xa805 & 0xFF},
	{0xa806 & 0xFF, 0xa806 & 0xFF},
	{0xa807 & 0xFF, 0xa80a & 0xFF},
	{0xa80b & 0xFF, 0xa80b & 0xFF},
	{0xa80c & 0xFF, 0xa822 & 0xFF},
	{0xa823 & 0xFF, 0xa827 & 0xFF},
	{0xa82c & 0xFF, 0xa82c & 0xFF},
	{0xa840 & 0xFF, 0xa873 & 0xFF},
	{0xa880 & 0xFF, 0xa881 & 0xFF},
	{0xa882 & 0xFF, 0xa8b3 & 0xFF},
	{0xa8b4 & 0xFF, 0xa8c5 & 0xFF},
	{0xa8d0 & 0xFF, 0xa8d9 & 0xFF},
	{0xa8e0 & 0xFF, 0xa8f1 & 0xFF},
	{0xa8f2 & 0xFF, 0xa8f7 & 0xFF},
	{0xa8fb & 0xFF, 0xa8fb & 0xFF},
	{0xa8fd & 0xFF, 0xa8fe & 0xFF},
	{0xa8ff & 0xFF, 0xa8ff & 0xFF},
	{0xa900 & 0xFF, 0xa909 & 0xFF},
	{0xa90a & 0xFF, 0xa925 & 0xFF},
	{0xa926 & 0xFF, 0xa92d & 0xFF},
	{0xa930 & 0xFF, 0xa946 & 0xFF},
	{0xa947 & 0xFF, 0xa953 & 0xFF},
	{0xa960 & 0xFF, 0xa97c & 0xFF},
	{0xa980 & 0xFF, 0xa983 & 0xFF},
	{0xa984 & 0xFF, 0xa9b2 & 0xFF},
	{0xa9b3 & 0xFF, 0xa9c0 & 0xFF},
	{0xa9cf & 0xFF, 0xa9cf & 0xFF},
	{0xa9d0 & 0xFF, 0xa9d9 & 0xFF},
	{0xa9e5 & 0xFF, 0xa9e5 & 0xFF},
	{0xa9f0 & 0xFF, 0xa9f9 & 0xFF},
	{0xaa00 & 0xFF, 0xaa28 & 0xFF},
	{0xaa29 & 0xFF, 0xaa36 & 0xFF},
	{0xaa40 & 0xFF, 0xaa42 & 0xFF},
	{0xaa43 & 0xFF, 0xaa43 & 0xFF},
	{0xaa44 & 0xFF, 0xaa4b & 0xFF},
	{0xaa4c & 0xFF, 0xaa4d & 0xFF},
	{0xaa50 & 0xFF, 0xaa59 & 0xFF},
	{0xaa7b & 0xFF, 0xaa7d & 0xFF},
	{0xaab0 & 0xFF, 0xaab0 & 0xFF},
	{0xaab2 & 0xFF, 0xaab4 & 0xFF},
	{0xaab7 & 0xFF, 0xaab8 & 0xFF},
	{0xaabe & 0xFF, 0xaabf & 0xFF},
	{0xaac1 & 0xFF, 0xaac1 & 0xFF},
	{0xaae0 & 0xFF, 0xaaea & 0xFF},
	{0xaaeb & 0xFF, 0xaaef & 0xFF},
	{0xaaf2 & 0xFF, 0xaaf4 & 0xFF},
	{0xaaf5 & 0xFF, 0xaaf6 & 0xFF},
	{0xab01 & 0xFF, 0xab06 & 0xFF},
	{0xab09 & 0xFF, 0xab0e & 0xFF},
	{0xab11 & 0xFF, 0xab16 & 0xFF},
	{0xab20 & 0xFF, 0xab26 & 0xFF},
	{0xab28 & 0xFF, 0xab2e & 0xFF},
	{0xab30 & 0xFF, 0xab69 & 0xFF},
	{0xab70 & 0xFF, 0xabe2 & 0xFF},
	{0xabe3 & 0xFF, 0xabea & 0xFF},
	{0xabec & 0xFF, 0xabed & 0xFF},
	{0xabf0 & 0xFF, 0xabf9 & 0xFF},
	{0xac00 & 0xFF, 0xacff & 0xFF},
	{0xad00 & 0xFF, 0xadff & 0xFF},
	{0xae00 & 0xFF, 0xaeff & 0xFF},
	{0xaf00 & 0xFF, 0xafff & 0xFF},
	{0xb000 & 0xFF, 0xb0ff & 0xFF},
	{0xb100 & 0xFF, 0xb1ff & 0xFF},
	{0xb200 & 0xFF, 0xb2ff & 0xFF},
	{0xb300 & 0xFF, 0xb3ff & 0xFF},
	{0xb400 & 0xFF, 0xb4ff & 0xFF},
	{0xb500 & 0xFF, 0xb5ff & 0xFF},
	{0xb600 & 0xFF, 0xb6ff & 0xFF},
	{0xb700 & 0xFF, 0xb7ff & 0xFF},
	{0xb800 & 0xFF, 0xb8ff & 0xFF},
	{0xb900 & 0xFF, 0xb9ff & 0xFF},
	{0xba00 & 0xFF, 0xbaff & 0xFF},
	{0xbb00 & 0xFF, 0xbbff & 0xFF},
	{0xbc00 & 0xFF, 0xbcff & 0xFF},
	{0xbd00 & 0xFF, 0xbdff & 0xFF},
	{0xbe00 & 0xFF, 0xbeff & 0xFF},
	{0xbf00 & 0xFF, 0xbfff & 0xFF},
	{0xc000 & 0xFF, 0xc0ff & 0xFF},
	{0xc100 & 0xFF, 0xc1ff & 0xFF},
	{0xc200 & 0xFF, 0xc2ff & 0xFF},
	{0xc300 & 0xFF, 0xc3ff & 0xFF},
	{0xc400 & 0xFF, 0xc4ff & 0xFF},
	{0xc500 & 0xFF, 0xc5ff & 0xFF},
	{0xc600 & 0xFF, 0xc6ff & 0xFF},
	{0xc700 & 0xFF, 0xc7ff & 0xFF},
	{0xc800 & 0xFF, 0xc8ff & 0xFF},
	{0xc900 & 0xFF, 0xc9ff & 0xFF},
	{0xca00 & 0xFF, 0xcaff & 0xFF},
	{0xcb00 & 0xFF, 0xcbff & 0xFF},
	{0xcc00 & 0xFF, 0xccff & 0xFF},
	{0xcd00 & 0xFF, 0xcdff & 0xFF},
	{0xce00 & 0xFF, 0xceff & 0xFF},
	{0xcf00 & 0xFF, 0xcfff & 0xFF},
	{0xd000 & 0xFF, 0xd0ff & 0xFF},
	{0xd100 & 0xFF, 0xd1ff & 0xFF},
	{0xd200 & 0xFF, 0xd2ff & 0xFF},
	{0xd300 & 0xFF, 0xd3ff & 0xFF},
	{0xd400 & 0xFF, 0xd4ff & 0xFF},
	{0xd500 & 0xFF, 0xd5ff & 0xFF},
	{0xd600 & 0xFF, 0xd6ff & 0xFF},
	{0xd700 & 0xFF, 0xd7a3 & 0xFF},
	{0xd7b0 & 0xFF, 0xd7c6 & 0xFF},
	{0xd7cb & 0xFF, 0xd7fb & 0xFF},
	{0xfb00 & 0xFF, 0xfb06 & 0xFF},
	{0xfb13 & 0xFF, 0xfb17 & 0xFF},
	{0xfb1d & 0xFF, 0xfb1d & 0xFF},
	{0xfb1e & 0xFF, 0xfb1e & 0xFF},
	{0xfb1f & 0xFF, 0xfb28 & 0xFF},
	{0xfb2a & 0xFF, 0xfb36 & 0xFF},
	{0xfb38 & 0xFF, 0xfb3c & 0xFF},
	{0xfb3e & 0xFF, 0xfb3e & 0xFF},
	{0xfb40 & 0xFF, 0xfb41 & 0xFF},
	{0xfb43 & 0xFF, 0xfb44 & 0xFF},
	{0xfb46 & 0xFF, 0xfb4f & 0xFF},
	{0xfb50 & 0xFF, 0xfbb1 & 0xFF},
	{0xfbd3 & 0xFF, 0xfbff & 0xFF},
	{0xfc00 & 0xFF, 0xfcff & 0xFF},
	{0xfd00 & 0xFF, 0xfd3d & 0xFF},
	{0xfd50 & 0xFF, 0xfd8f & 0xFF},
	{0xfd92 & 0xFF, 0xfdc7 & 0xFF},
	{0xfdf0 & 0xFF, 0xfdfb & 0xFF},
	{0xfe00 & 0xFF, 0xfe0f & 0xFF},
	{0xfe13 & 0xFF, 0xfe13 & 0xFF},
	{0xfe20 & 0xFF, 0xfe2f & 0xFF},
	{0xfe33 & 0xFF, 0xfe34 & 0xFF},
	{0xfe4d & 0xFF, 0xfe4f & 0xFF},
	{0xfe50 & 0xFF, 0xfe50 & 0xFF},
	{0xfe52 & 0xFF, 0xfe52 & 0xFF},
	{0xfe54 & 0xFF, 0xfe54 & 0xFF},
	{0xfe55 & 0xFF, 0xfe55 & 0xFF},
	{0xfe70 & 0xFF, 0xfe74 & 0xFF},
	{0xfe76 & 0xFF, 0xfefc & 0xFF},
	{0xfeff & 0xFF, 0xfeff & 0xFF},
	{0xff07 & 0xFF, 0xff07 & 0xFF},
	{0xff0c & 0xFF, 0xff0c & 0xFF},
	{0xff0e & 0xFF, 0xff0e & 0xFF},
	{0xff10 & 0xFF, 0xff19 & 0xFF},
	{0xff1a & 0xFF, 0xff1a & 0xFF},
	{0xff1b & 0xFF, 0xff1b & 0xFF},
	{0xff21 & 0xFF, 0xff3a & 0xFF},
	{0xff3f & 0xFF, 0xff3f & 0xFF},
	{0xff41 & 0xFF, 0xff5a & 0xFF},
	{0xff66 & 0xFF, 0xff9d & 0xFF},
	{0xff9e & 0xFF, 0xff9f & 0xFF},
	{0xffa0 & 0xFF, 0xffbe & 0xFF},
	{0xffc2 & 0xFF, 0xffc7 & 0xFF},
	{0xffca & 0xFF, 0xffcf & 0xFF},
	{0xffd2 & 0xFF, 0xffd7 & 0xFF},
	{0xffda & 0xFF, 0xffdc & 0xFF},
	{0xfff9 & 0xFF, 0xfffb & 0xFF},
	{0x10000 & 0xFF, 0x1000b & 0xFF},
	{0x1000d & 0xFF, 0x10026 & 0xFF},
	{0x10028 & 0xFF, 0x1003a & 0xFF},
	{0x1003c & 0xFF, 0x1003d & 0xFF},
	{0x1003f & 0xFF, 0x1004d & 0xFF},
	{0x10050 & 0xFF, 0x1005d & 0xFF},
	{0x10080 & 0xFF, 0x100fa & 0xFF},
	{0x10140 & 0xFF, 0x10174 & 0xFF},
	{0x101fd & 0xFF, 0x101fd & 0xFF},
	{0x10280 & 0xFF, 0x1029c & 0xFF},
	{0x102a0 & 0xFF, 0x102d0 & 0xFF},
	{0x102e0 & 0xFF, 0x102e0 & 0xFF},
	{0x10300 & 0xFF, 0x1031f & 0xFF},
	{0x1032d & 0xFF, 0x1034a & 0xFF},
	{0x10350 & 0xFF, 0x10375 & 0xFF},
	{0x10376 & 0xFF, 0x1037a & 0xFF},
	{0x10380 & 0xFF, 0x1039d & 0xFF},
	{0x103a0 & 0xFF, 0x103c3 & 0xFF},
	{0x103c8 & 0xFF, 0x103cf & 0xFF},
	{0x103d1 & 0xFF, 0x103d5 & 0xFF},
	{0x10400 & 0xFF, 0x1049d & 0xFF},
	{0x104a0 & 0xFF, 0x104a9 & 0xFF},
	{0x104b0 & 0xFF, 0x104d3 & 0xFF},
	{0x104d8 & 0xFF, 0x104fb & 0xFF},
	{0x10500 & 0xFF, 0x10527 & 0xFF},
	{0x10530 & 0xFF, 0x10563 & 0xFF},
	{0x10570 & 0xFF, 0x1057a & 0xFF},
	{0x1057c & 0xFF, 0x1058a & 0xFF},
	{0x1058c & 0xFF, 0x10592 & 0xFF},
	{0x10594 & 0xFF, 0x10595 & 0xFF},
	{0x10597 & 0xFF, 0x105a1 & 0xFF},
	{0x105a3 & 0xFF, 0x105b1 & 0xFF},
	{0x105b3 & 0xFF, 0x105b9 & 0xFF},
	{0x105bb & 0xFF, 0x105bc & 0xFF},
	{0x105c0 & 0xFF, 0x105f3 & 0xFF},
	{0x10600 & 0xFF, 0x106ff & 0xFF},
	{0x10700 & 0xFF, 0x10736 & 0xFF},
	{0x10740 & 0xFF, 0x10755 & 0xFF},
	{0x10760 & 0xFF, 0x10767 & 0xFF},
	{0x10780 & 0xFF, 0x10785 & 0xFF},
	{0x10787 & 0xFF, 0x107b0 & 0xFF},
	{0x107b2 & 0xFF, 0x107ba & 0xFF},
	{0x10800 & 0xFF, 0x10805 & 0xFF},
	{0x10808 & 0xFF, 0x10808 & 0xFF},
	{0x1080a & 0xFF, 0x10835 & 0xFF},
	{0x10837 & 0xFF, 0x10838 & 0xFF},
	{0x1083c & 0xFF, 0x1083c & 0xFF},
	{0x1083f & 0xFF, 0x10855 & 0xFF},
	{0x10860 & 0xFF, 0x10876 & 0xFF},
	{0x10880 & 0xFF, 0x1089e & 0xFF},
	{0x108e0 & 0xFF, 0x108f2 & 0xFF},
	{0x108f4 & 0xFF, 0x108f5 & 0xFF},
	{0x10900 & 0xFF, 0x10915 & 0xFF},
	{0x10920 & 0xFF, 0x10939 & 0xFF},
	{0x10980 & 0xFF, 0x109b7 & 0xFF},
	{0x109be & 0xFF, 0x109bf & 0xFF},
	{0x10a00 & 0xFF, 0x10a00 & 0xFF},
	{0x10a01 & 0xFF, 0x10a03 & 0xFF},
	{0x10a05 & 0xFF, 0x10a06 & 0xFF},
	{0x10a0c & 0xFF, 0x10a0f & 0xFF},
	{0x10a10 & 0xFF, 0x10a13 & 0xFF},
	{0x10a15 & 0xFF, 0x10a17 & 0xFF},
	{0x10a19 & 0xFF, 0x10a35 & 0xFF},
	{0x10a38 & 0xFF, 0x10a3a & 0xFF},
	{0x10a3f & 0xFF, 0x10a3f & 0xFF},
	{0x10a60 & 0xFF, 0x10a7c & 0xFF},
	{0x10a80 & 0xFF, 0x10a9c & 0xFF},
	{0x10ac0 & 0xFF, 0x10ac7 & 0xFF},
	{0x10ac9 & 0xFF, 0x10ae4 & 0xFF},
	{0x10ae5 & 0xFF, 0x10ae6 & 0xFF},
	{0x10b00 & 0xFF, 0x10b35 & 0xFF},
	{0x10b40 & 0xFF, 0x10b55 & 0xFF},
	{0x10b60 & 0xFF, 0x10b72 & 0xFF},
	{0x10b80 & 0xFF, 0x10b91 & 0xFF},
	{0x10c00 & 0xFF, 0x10c48 & 0xFF},
	{0x10c80 & 0xFF, 0x10cb2 & 0xFF},
	{0x10cc0 & 0xFF, 0x10cf2 & 0xFF},
	{0x10d00 & 0xFF, 0x10d23 & 0xFF},
	{0x10d24 & 0xFF, 0x10d27 & 0xFF},
	{0x10d30 & 0xFF, 0x10d39 & 0xFF},
	{0x10d40 & 0xFF, 0x10d49 & 0xFF},
	{0x10d4a & 0xFF, 0x10d65 & 0xFF},
	{0x10d69 & 0xFF, 0x10d6d & 0xFF},
	{0x10d6f & 0xFF, 0x10d85 & 0xFF},
	{0x10e80 & 0xFF, 0x10ea9 & 0xFF},
	{0x10eab & 0xFF, 0x10eac & 0xFF},
	{0x10eb0 & 0xFF, 0x10eb1 & 0xFF},
	{0x10ec2 & 0xFF, 0x10ec4 & 0xFF},
	{0x10efc & 0xFF, 0x10eff & 0xFF},
	{0x10f00 & 0xFF, 0x10f1c & 0xFF},
	{0x10f27 & 0xFF, 0x10f27 & 0xFF},
	{0x10f30 & 0xFF, 0x10f45 & 0xFF},
	{0x10f46 & 0xFF, 0x10f50 & 0xFF},
	{0x10f70 & 0xFF, 0x10f81 & 0xFF},
	{0x10f82 & 0xFF, 0x10f85 & 0xFF},
	{0x10fb0 & 0xFF, 0x10fc4 & 0xFF},
	{0x10fe0 & 0xFF, 0x10ff6 & 0xFF},
	{0x11000 & 0xFF, 0x11002 & 0xFF},
	{0x11003 & 0xFF, 0x11037 & 0xFF},
	{0x11038 & 0xFF, 0x11046 & 0xFF},
	{0x11066 & 0xFF, 0x1106f & 0xFF},
	{0x11070 & 0xFF, 0x11070 & 0xFF},
	{0x11071 & 0xFF, 0x11072 & 0xFF},
	{0x11073 & 0xFF, 0x11074 & 0xFF},
	{0x11075 & 0xFF, 0x11075 & 0xFF},
	{0x1107f & 0xFF, 0x11082 & 0xFF},
	{0x11083 & 0xFF, 0x110af & 0xFF},
	{0x110b0 & 0xFF, 0x110ba & 0xFF},
	{0x110bd & 0xFF, 0x110bd & 0xFF},
	{0x110c2 & 0xFF, 0x110c2 & 0xFF},
	{0x110cd & 0xFF, 0x110cd & 0xFF},
	{0x110d0 & 0xFF, 0x110e8 & 0xFF},
	{0x110f0 & 0xFF, 0x110f9 & 0xFF},
	{0x11100 & 0xFF, 0x11102 & 0xFF},
	{0x11103 & 0xFF, 0x11126 & 0xFF},
	{0x11127 & 0xFF, 0x11134 & 0xFF},
	{0x11136 & 0xFF, 0x1113f & 0xFF},
	{0x11144 & 0xFF, 0x11144 & 0xFF},
	{0x11145 & 0xFF, 0x11146 & 0xFF},
	{0x11147 & 0xFF, 0x11147 & 0xFF},
	{0x11150 & 0xFF, 0x11172 & 0xFF},
	{0x11173 & 0xFF, 0x11173 & 0xFF},
	{0x11176 & 0xFF, 0x11176 & 0xFF},
	{0x11180 & 0xFF, 0x11182 & 0xFF},
	{0x11183 & 0xFF, 0x111b2 & 0xFF},
	{0x111b3 & 0xFF, 0x111c0 & 0xFF},
	{0x111c1 & 0xFF, 0x111c4 & 0xFF},
	{0x111c9 & 0xFF, 0x111cc & 0xFF},
	{0x111ce & 0xFF, 0x111cf & 0xFF},
	{0x111d0 & 0xFF, 0x111d9 & 0xFF},
	{0x111da & 0xFF, 0x111da & 0xFF},
	{0x111dc & 0xFF, 0x111dc & 0xFF},
	{0x11200 & 0xFF, 0x11211 & 0xFF},
	{0x11213 & 0xFF, 0x1122b & 0xFF},
	{0x1122c & 0xFF, 0x11237 & 0xFF},
	{0x1123e & 0xFF, 0x1123e & 0xFF},
	{0x1123f & 0xFF, 0x11240 & 0xFF},
	{0x11241 & 0xFF, 0x11241 & 0xFF},
	{0x11280 & 0xFF, 0x11286 & 0xFF},
	{0x11288 & 0xFF, 0x11288 & 0xFF},
	{0x1128a & 0xFF, 0x1128d & 0xFF},
	{0x1128f & 0xFF, 0x1129d & 0xFF},
	{0x1129f & 0xFF, 0x112a8 & 0xFF},
	{0x112b0 & 0xFF, 0x112de & 0xFF},
	{0x112df & 0xFF, 0x112ea & 0xFF},
	{0x112f0 & 0xFF, 0x112f9 & 0xFF},
	{0x11300 & 0xFF, 0x11303 & 0xFF},
	{0x11305 & 0xFF, 0x1130c & 0xFF},
	{0x1130f & 0xFF, 0x11310 & 0xFF},
	{0x11313 & 0xFF, 0x11328 & 0xFF},
	{0x1132a & 0xFF, 0x11330 & 0xFF},
	{0x11332 & 0xFF, 0x11333 & 0xFF},
	{0x11335 & 0xFF, 0x11339 & 0xFF},
	{0x1133b & 0xFF, 0x1133c & 0xFF},
	{0x1133d & 0xFF, 0x1133d & 0xFF},
	{0x1133e & 0xFF, 0x11344 & 0xFF},
	{0x11347 & 0xFF, 0x11348 & 0xFF},
	{0x1134b & 0xFF, 0x1134d & 0xFF},
	{0x11350 & 0xFF, 0x11350 & 0xFF},
	{0x11357 & 0xFF, 0x11357 & 0xFF},
	{0x1135d & 0xFF, 0x11361 & 0xFF},
	{0x11362 & 0xFF, 0x11363 & 0xFF},
	{0x11366 & 0xFF, 0x1136c & 0xFF},
	{0x11370 & 0xFF, 0x11374 & 0xFF},
	{0x11380 & 0xFF, 0x11389 & 0xFF},
	{0x1138b & 0xFF, 0x1138b & 0xFF},
	{0x1138e & 0xFF, 0x1138e & 0xFF},
	{0x11390 & 0xFF, 0x113b5 & 0xFF},
	{0x113b7 & 0xFF, 0x113b7 & 0xFF},
	{0x113b8 & 0xFF, 0x113c0 & 0xFF},
	{0x113c2 & 0xFF, 0x113c2 & 0xFF},
	{0x113c5 & 0xFF, 0x113c5 & 0xFF},
	{0x113c7 & 0xFF, 0x113ca & 0xFF},
	{0x113cc & 0xFF, 0x113d0 & 0xFF},
	{0x113d1 & 0xFF, 0x113d1 & 0xFF},
	{0x113d2 & 0xFF, 0x113d2 & 0xFF},
	{0x113d3 & 0xFF, 0x113d3 & 0xFF},
	{0x113e1 & 0xFF, 0x113e2 & 0xFF},
	{0x11400 & 0xFF, 0x11434 & 0xFF},
	{0x11435 & 0xFF, 0x11446 & 0xFF},
	{0x11447 & 0xFF, 0x1144a & 0xFF},
	{0x11450 & 0xFF, 0x11459 & 0xFF},
	{0x1145e & 0xFF, 0x1145e & 0xFF},
	{0x1145f & 0xFF, 0x11461 & 0xFF},
	{0x11480 & 0xFF, 0x114af & 0xFF},
	{0x114b0 & 0xFF, 0x114c3 & 0xFF},
	{0x114c4 & 0xFF, 0x114c5 & 0xFF},
	{0x114c7 & 0xFF, 0x114c7 & 0xFF},
	{0x114d0 & 0xFF, 0x114d9 & 0xFF},
	{0x11580 & 0xFF, 0x115ae & 0xFF},
	{0x115af & 0xFF, 0x115b5 & 0xFF},
	{0x115b8 & 0xFF, 0x115c0 & 0xFF},
	{0x115d8 & 0xFF, 0x115db & 0xFF},
	{0x115dc & 0xFF, 0x115dd & 0xFF},
	{0x11600 & 0xFF, 0x1162f & 0xFF},
	{0x11630 & 0xFF, 0x11640 & 0xFF},
	{0x11644 & 0xFF, 0x11644 & 0xFF},
	{0x11650 & 0xFF, 0x11659 & 0xFF},
	{0x11680 & 0xFF, 0x116aa & 0xFF},
	{0x116ab & 0xFF, 0x116b7 & 0xFF},
	{0x116b8 & 0xFF, 0x116b8 & 0xFF},
	{0x116c0 & 0xFF, 0x116c9 & 0xFF},
	{0x116d0 & 0xFF, 0x116e3 & 0xFF},
	{0x1171d & 0xFF, 0x1172b & 0xFF},
	{0x11730 & 0xFF, 0x11739 & 0xFF},
	{0x11800 & 0xFF, 0x1182b & 0xFF},
	{0x1182c & 0xFF, 0x1183a & 0xFF},
	{0x118a0 & 0xFF, 0x118df & 0xFF},
	{0x118e0 & 0xFF, 0x118e9 & 0xFF},
	{0x118ff & 0xFF, 0x118ff & 0xFF},
	{0x11900 & 0xFF, 0x11906 & 0xFF},
	{0x11909 & 0xFF, 0x11909 & 0xFF},
	{0x1190c & 0xFF, 0x11913 & 0xFF},
	{0x11915 & 0xFF, 0x11916 & 0xFF},
	{0x11918 & 0xFF, 0x1192f & 0xFF},
	{0x11930 & 0xFF, 0x11935 & 0xFF},
	{0x11937 & 0xFF, 0x11938 & 0xFF},
	{0x1193b & 0xFF, 0x1193e & 0xFF},
	{0x1193f & 0xFF, 0x1193f & 0xFF},
	{0x11940 & 0xFF, 0x11940 & 0xFF},
	{0x11941 & 0xFF, 0x11941 & 0xFF},
	{0x11942 & 0xFF, 0x11943 & 0xFF},
	{0x11950 & 0xFF, 0x11959 & 0xFF},
	{0x119a0 & 0xFF, 0x119a7 & 0xFF},
	{0x119aa & 0xFF, 0x119d0 & 0xFF},
	{0x119d1 & 0xFF, 0x119d7 & 0xFF},
	{0x119da & 0xFF, 0x119e0 & 0xFF},
	{0x119e1 & 0xFF, 0x119e1 & 0xFF},
	{0x119e3 & 0xFF, 0x119e3 & 0xFF},
	{0x119e4 & 0xFF, 0x119e4 & 0xFF},
	{0x11a00 & 0xFF, 0x11a00 & 0xFF},
	{0x11a01 & 0xFF, 0x11a0a & 0xFF},
	{0x11a0b & 0xFF, 0x11a32 & 0xFF},
	{0x11a33 & 0xFF, 0x11a39 & 0xFF},
	{0x11a3a & 0xFF, 0x11a3a & 0xFF},
	{0x11a3b & 0xFF, 0x11a3e & 0xFF},
	{0x11a47 & 0xFF, 0x11a47 & 0xFF},
	{0x11a50 & 0xFF, 0x11a50 & 0xFF},
	{0x11a51 & 0xFF, 0x11a5b & 0xFF},
	{0x11a5c & 0xFF, 0x11a89 & 0xFF},
	{0x11a8a & 0xFF, 0x11a99 & 0xFF},
	{0x11a9d & 0xFF, 0x11a9d & 0xFF},
	{0x11ab0 & 0xFF, 0x11af8 & 0xFF},
	{0x11bc0 & 0xFF, 0x11be0 & 0xFF},
	{0x11bf0 & 0xFF, 0x11bf9 & 0xFF},
	{0x11c00 & 0xFF, 0x11c08 & 0xFF},
	{0x11c0a & 0xFF, 0x11c2e & 0xFF},
	{0x11c2f & 0xFF, 0x11c36 & 0xFF},
	{0x11c38 & 0xFF, 0x11c3f & 0xFF},
	{0x11c40 & 0xFF, 0x11c40 & 0xFF},
	{0x11c50 & 0xFF, 0x11c59 & 0xFF},
	{0x11c72 & 0xFF, 0x11c8f & 0xFF},
	{0x11c92 & 0xFF, 0x11ca7 & 0xFF},
	{0x11ca9 & 0xFF, 0x11cb6 & 0xFF},
	{0x11d00 & 0xFF, 0x11d06 & 0xFF},
	{0x11d08 & 0xFF, 0x11d09 & 0xFF},
	{0x11d0b & 0xFF, 0x11d30 & 0xFF},
	{0x11d31 & 0xFF, 0x11d36 & 0xFF},
	{0x11d3a & 0xFF, 0x11d3a & 0xFF},
	{0x11d3c & 0xFF, 0x11d3d & 0xFF},
	{0x11d3f & 0xFF, 0x11d45 & 0xFF},
	{0x11d46 & 0xFF, 0x11d46 & 0xFF},
	{0x11d47 & 0xFF, 0x11d47 & 0xFF},
	{0x11d50 & 0xFF, 0x11d59 & 0xFF},
	{0x11d60 & 0xFF, 0x11d65 & 0xFF},
	{0x11d67 & 0xFF, 0x11d68 & 0xFF},
	{0x11d6a & 0xFF, 0x11d89 & 0xFF},
	{0x11d8a & 0xFF, 0x11d8e & 0xFF},
	{0x11d90 & 0xFF, 0x11d91 & 0xFF},
	{0x11d93 & 0xFF, 0x11d97 & 0xFF},
	{0x11d98 & 0xFF, 0x11d98 & 0xFF},
	{0x11da0 & 0xFF, 0x11da9 & 0xFF},
	{0x11ee0 & 0xFF, 0x11ef2 & 0xFF},
	{0x11ef3 & 0xFF, 0x11ef6 & 0xFF},
	{0x11f00 & 0xFF, 0x11f01 & 0xFF},
	{0x11f02 & 0xFF, 0x11f02 & 0xFF},
	{0x11f03 & 0xFF, 0x11f03 & 0xFF},
	{0x11f04 & 0xFF, 0x11f10 & 0xFF},
	{0x11f12 & 0xFF, 0x11f33 & 0xFF},
	{0x11f34 & 0xFF, 0x11f3a & 0xFF},
	{0x11f3e & 0xFF, 0x11f42 & 0xFF},
	{0x11f50 & 0xFF, 0x11f59 & 0xFF},
	{0x11f5a & 0xFF, 0x11f5a & 0xFF},
	{0x11fb0 & 0xFF, 0x11fb0 & 0xFF},
	{0x12000 & 0xFF, 0x120ff & 0xFF},
	{0x12100 & 0xFF, 0x121ff & 0xFF},
	{0x12200 & 0xFF, 0x122ff & 0xFF},
	{0x12300 & 0xFF, 0x12399 & 0xFF},
	{0x12400 & 0xFF, 0x1246e & 0xFF},
	{0x12480 & 0xFF, 0x124ff & 0xFF},
	{0x12500 & 0xFF, 0x12543 & 0xFF},
	{0x12f90 & 0xFF, 0x12ff0 & 0xFF},
	{0x13000 & 0xFF, 0x130ff & 0xFF},
	{0x13100 & 0xFF, 0x131ff & 0xFF},
	{0x13200 & 0xFF, 0x132ff & 0xFF},
	{0x13300 & 0xFF, 0x133ff & 0xFF},
	{0x13400 & 0xFF, 0x1342f & 0xFF},
	{0x13430 & 0xFF, 0x1343f & 0xFF},
	{0x13440 & 0xFF, 0x13440 & 0xFF},
	{0x13441 & 0xFF, 0x13446 & 0xFF},
	{0x13447 & 0xFF, 0x13455 & 0xFF},
	{0x13460 & 0xFF, 0x134ff & 0xFF},
	{0x13500 & 0xFF, 0x135ff & 0xFF},
	{0x13600 & 0xFF, 0x136ff & 0xFF},
	{0x13700 & 0xFF, 0x137ff & 0xFF},
	{0x13800 & 0xFF, 0x138ff & 0xFF},
	{0x13900 & 0xFF, 0x139ff & 0xFF},
	{0x13a00 & 0xFF, 0x13aff & 0xFF},
	{0x13b00 & 0xFF, 0x13bff & 0xFF},
	{0x13c00 & 0xFF, 0x13cff & 0xFF},
	{0x13d00 & 0xFF, 0x13dff & 0xFF},
	{0x13e00 & 0xFF, 0x13eff & 0xFF},
	{0x13f00 & 0xFF, 0x13fff & 0xFF},
	{0x14000 & 0xFF, 0x140ff & 0xFF},
	{0x14100 & 0xFF, 0x141ff & 0xFF},
	{0x14200 & 0xFF, 0x142ff & 0xFF},
	{0x14300 & 0xFF, 0x143fa & 0xFF},
	{0x14400 & 0xFF, 0x144ff & 0xFF},
	{0x14500 & 0xFF, 0x145ff & 0xFF},
	{0x14600 & 0xFF, 0x14646 & 0xFF},
	{0x16100 & 0xFF, 0x1611d & 0xFF},
	{0x1611e & 0xFF, 0x1612f & 0xFF},
	{0x16130 & 0xFF, 0x16139 & 0xFF},
	{0x16800 & 0xFF, 0x168ff & 0xFF},
	{0x16900 & 0xFF, 0x169ff & 0xFF},
	{0x16a00 & 0xFF, 0x16a38 & 0xFF},
	{0x16a40 & 0xFF, 0x16a5e & 0xFF},
	{0x16a60 & 0xFF, 0x16a69 & 0xFF},
	{0x16a70 & 0xFF, 0x16abe & 0xFF},
	{0x16ac0 & 0xFF, 0x16ac9 & 0xFF},
	{0x16ad0 & 0xFF, 0x16aed & 0xFF},
	{0x16af0 & 0xFF, 0x16af4 & 0xFF},
	{0x16b00 & 0xFF, 0x16b2f & 0xFF},
	{0x16b30 & 0xFF, 0x16b36 & 0xFF},
	{0x16b40 & 0xFF, 0x16b43 & 0xFF},
	{0x16b50 & 0xFF, 0x16b59 & 0xFF},
	{0x16b63 & 0xFF, 0x16b77 & 0xFF},
	{0x16b7d & 0xFF, 0x16b8f & 0xFF},
	{0x16d40 & 0xFF, 0x16d6c & 0xFF},
	{0x16d70 & 0xFF, 0x16d79 & 0xFF},
	{0x16e40 & 0xFF, 0x16e7f & 0xFF},
	{0x16f00 & 0xFF, 0x16f4a & 0xFF},
	{0x16f4f & 0xFF, 0x16f4f & 0xFF},
	{0x16f50 & 0xFF, 0x16f50 & 0xFF},
	{0x16f51 & 0xFF, 0x16f87 & 0xFF},
	{0x16f8f & 0xFF, 0x16f92 & 0xFF},
	{0x16f93 & 0xFF, 0x16f9f & 0xFF},
	{0x16fe0 & 0xFF, 0x16fe1 & 0xFF},
	{0x16fe3 & 0xFF, 0x16fe3 & 0xFF},
	{0x16fe4 & 0xFF, 0x16fe4 & 0xFF},
	{0x16ff0 & 0xFF, 0x16ff1 & 0xFF},
	{0x1aff0 & 0xFF, 0x1aff3 & 0xFF},
	{0x1aff5 & 0xFF, 0x1affb & 0xFF},
	{0x1affd & 0xFF, 0x1affe & 0xFF},
	{0x1b000 & 0xFF, 0x1b000 & 0xFF},
	{0x1b120 & 0xFF, 0x1b122 & 0xFF},
	{0x1b155 & 0xFF, 0x1b155 & 0xFF},
	{0x1b164 & 0xFF, 0x1b167 & 0xFF},
	{0x1bc00 & 0xFF, 0x1bc6a & 0xFF},
	{0x1bc70 & 0xFF, 0x1bc7c & 0xFF},
	{0x1bc80 & 0xFF, 0x1bc88 & 0xFF},
	{0x1bc90 & 0xFF, 0x1bc99 & 0xFF},
	{0x1bc9d & 0xFF, 0x1bc9e & 0xFF},
	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
	{0x1ccf0 & 0xFF, 0x1ccf9 & 0xFF},
	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
	{0x1d165 & 0xFF, 0x1d169 & 0xFF},
	{0x1d16d & 0xFF, 0x1d172 & 0xFF},
	{0x1d173 & 0xFF, 0x1d17a & 0xFF},
	{0x1d17b & 0xFF, 0x1d182 & 0xFF},
	{0x1d185 & 0xFF, 0x1d18b & 0xFF},
	{0x1d1aa & 0xFF, 0x1d1ad & 0xFF},
	{0x1d242 & 0xFF, 0x1d244 & 0xFF},
	{0x1d400 & 0xFF, 0x1d454 & 0xFF},
	{0x1d456 & 0xFF, 0x1d49c & 0xFF},
	{0x1d49e & 0xFF, 0x1d49f & 0xFF},
	{0x1d4a2 & 0xFF, 0x1d4a2 & 0xFF},
	{0x1d4a5 & 0xFF, 0x1d4a6 & 0xFF},
	{0x1d4a9 & 0xFF, 0x1d4ac & 0xFF},
	{0x1d4ae & 0xFF, 0x1d4b9 & 0xFF},
	{0x1d4bb & 0xFF, 0x1d4bb & 0xFF},
	{0x1d4bd & 0xFF, 0x1d4c3 & 0xFF},
	{0x1d4c5 & 0xFF, 0x1d4ff & 0xFF},
	{0x1d500 & 0xFF, 0x1d505 & 0xFF},
	{0x1d507 & 0xFF, 0x1d50a & 0xFF},
	{0x1d50d & 0xFF, 0x1d514 & 0xFF},
	{0x1d516 & 0xFF, 0x1d51c & 0xFF},
	{0x1d51e & 0xFF, 0x1d539 & 0xFF},
	{0x1d53b & 0xFF, 0x1d53e & 0xFF},
	{0x1d540 & 0xFF, 0x1d544 & 0xFF},
	{0x1d546 & 0xFF, 0x1d546 & 0xFF},
	{0x1d54a & 0xFF, 0x1d550 & 0xFF},
	{0x1d552 & 0xFF, 0x1d5ff & 0xFF},
	{0x1d600 & 0xFF, 0x1d6a5 & 0xFF},
	{0x1d6a8 & 0xFF, 0x1d6c0 & 0xFF},
	{0x1d6c2 & 0xFF, 0x1d6da & 0xFF},
	{0x1d6dc & 0xFF, 0x1d6fa & 0xFF},
	{0x1d6fc & 0xFF, 0x1d6ff & 0xFF},
	{0x1d700 & 0xFF, 0x1d714 & 0xFF},
	{0x1d716 & 0xFF, 0x1d734 & 0xFF},
	{0x1d736 & 0xFF, 0x1d74e & 0xFF},
	{0x1d750 & 0xFF, 0x1d76e & 0xFF},
	{0x1d770 & 0xFF, 0x1d788 & 0xFF},
	{0x1d78a & 0xFF, 0x1d7a8 & 0xFF},
	{0x1d7aa & 0xFF, 0x1d7c2 & 0xFF},
	{0x1d7c4 & 0xFF, 0x1d7cb & 0xFF},
	{0x1d7ce & 0xFF, 0x1d7ff & 0xFF},
	{0x1da00 & 0xFF, 0x1da36 & 0xFF},
	{0x1da3b & 0xFF, 0x1da6c & 0xFF},
	{0x1da75 & 0xFF, 0x1da75 & 0xFF},
	{0x1da84 & 0xFF, 0x1da84 & 0xFF},
	{0x1da9b & 0xFF, 0x1da9f & 0xFF},
	{0x1daa1 & 0xFF, 0x1daaf & 0xFF},
	{0x1df00 & 0xFF, 0x1df1e & 0xFF},
	{0x1df25 & 0xFF, 0x1df2a & 0xFF},
	{0x1e000 & 0xFF, 0x1e006 & 0xFF},
	{0x1e008 & 0xFF, 0x1e018 & 0xFF},
	{0x1e01b & 0xFF, 0x1e021 & 0xFF},
	{0x1e023 & 0xFF, 0x1e024 & 0xFF},
	{0x1e026 & 0xFF, 0x1e02a & 0xFF},
	{0x1e030 & 0xFF, 0x1e06d & 0xFF},
	{0x1e08f & 0xFF, 0x1e08f & 0xFF},
	{0x1e100 & 0xFF, 0x1e12c & 0xFF},
	{0x1e130 & 0xFF, 0x1e136 & 0xFF},
	{0x1e137 & 0xFF, 0x1e13d & 0xFF},
	{0x1e140 & 0xFF, 0x1e149 & 0xFF},
	{0x1e14e & 0xFF, 0x1e14e & 0xFF},
	{0x1e290 & 0xFF, 0x1e2ad & 0xFF},
	{0x1e2ae & 0xFF, 0x1e2ae & 0xFF},
	{0x1e2c0 & 0xFF, 0x1e2eb & 0xFF},
	{0x1e2ec & 0xFF, 0x1e2ef & 0xFF},
	{0x1e2f0 & 0xFF, 0x1e2f9 & 0xFF},
	{0x1e4d0 & 0xFF, 0x1e4eb & 0xFF},
	{0x1e4ec & 0xFF, 0x1e4ef & 0xFF},
	{0x1e4f0 & 0xFF, 0x1e4f9 & 0xFF},
	{0x1e5d0 & 0xFF, 0x1e5ed & 0xFF},
	{0x1e5ee & 0xFF, 0x1e5ef & 0xFF},
	{0x1e5f0 & 0xFF, 0x1e5f0 & 0xFF},
	{0x1e5f1 & 0xFF, 0x1e5fa & 0xFF},
	{0x1e7e0 & 0xFF, 0x1e7e6 & 0xFF},
	{0x1e7e8 & 0xFF, 0x1e7eb & 0xFF},
	{0x1e7ed & 0xFF, 0x1e7ee & 0xFF},
	{0x1e7f0 & 0xFF, 0x1e7fe & 0xFF},
	{0x1e800 & 0xFF, 0x1e8c4 & 0xFF},
	{0x1e8d0 & 0xFF, 0x1e8d6 & 0xFF},
	{0x1e900 & 0xFF, 0x1e943 & 0xFF},
	{0x1e944 & 0xFF, 0x1e94a & 0xFF},
	{0x1e94b & 0xFF, 0x1e94b & 0xFF},
	{0x1e950 & 0xFF, 0x1e959 & 0xFF},
	{0x1ee00 & 0xFF, 0x1ee03 & 0xFF},
	{0x1ee05 & 0xFF, 0x1ee1f & 0xFF},
	{0x1ee21 & 0xFF, 0x1ee22 & 0xFF},
	{0x1ee24 & 0xFF, 0x1ee24 & 0xFF},
	{0x1ee27 & 0xFF, 0x1ee27 & 0xFF},
	{0x1ee29 & 0xFF, 0x1ee32 & 0xFF},
	{0x1ee34 & 0xFF, 0x1ee37 & 0xFF},
	{0x1ee39 & 0xFF, 0x1ee39 & 0xFF},
	{0x1ee3b & 0xFF, 0x1ee3b & 0xFF},
	{0x1ee42 & 0xFF, 0x1ee42 & 0xFF},
	{0x1ee47 & 0xFF, 0x1ee47 & 0xFF},
	{0x1ee49 & 0xFF, 0x1ee49 & 0xFF},
	{0x1ee4b & 0xFF, 0x1ee4b & 0xFF},
	{0x1ee4d & 0xFF, 0x1ee4f & 0xFF},
	{0x1ee51 & 0xFF, 0x1ee52 & 0xFF},
	{0x1ee54 & 0xFF, 0x1ee54 & 0xFF},
	{0x1ee57 & 0xFF, 0x1ee57 & 0xFF},
	{0x1ee59 & 0xFF, 0x1ee59 & 0xFF},
	{0x1ee5b & 0xFF, 0x1ee5b & 0xFF},
	{0x1ee5d & 0xFF, 0x1ee5d & 0xFF},
	{0x1ee5f & 0xFF, 0x1ee5f & 0xFF},
	{0x1ee61 & 0xFF, 0x1ee62 & 0xFF},
	{0x1ee64 & 0xFF, 0x1ee64 & 0xFF},
	{0x1ee67 & 0xFF, 0x1ee6a & 0xFF},
	{0x1ee6c & 0xFF, 0x1ee72 & 0xFF},
	{0x1ee74 & 0xFF, 0x1ee77 & 0xFF},
	{0x1ee79 & 0xFF, 0x1ee7c & 0xFF},
	{0x1ee7e & 0xFF, 0x1ee7e & 0xFF},
	{0x1ee80 & 0xFF, 0x1ee89 & 0xFF},
	{0x1ee8b & 0xFF, 0x1ee9b & 0xFF},
	{0x1eea1 & 0xFF, 0x1eea3 & 0xFF},
	{0x1eea5 & 0xFF, 0x1eea9 & 0xFF},
	{0x1eeab & 0xFF, 0x1eebb & 0xFF},
	{0x1f130 & 0xFF, 0x1f149 & 0xFF},
	{0x1f150 & 0xFF, 0x1f169 & 0xFF},
	{0x1f170 & 0xFF, 0x1f189 & 0xFF},
	{0x1f1e6 & 0xFF, 0x1f1ff & 0xFF},
	{0x1f3fb & 0xFF, 0x1f3ff & 0xFF},
	{0x1fbf0 & 0xFF, 0x1fbf9 & 0xFF},
	{0xe0001 & 0xFF, 0xe0001 & 0xFF},
	{0xe0020 & 0xFF, 0xe007f & 0xFF},
	{0xe0100 & 0xFF, 0xe01ef & 0xFF}};

static const uint8_t unicode_classtab[]={
	UNICODE_WB_LF,
	UNICODE_WB_Newline,
	UNICODE_WB_CR,
	UNICODE_WB_WSegSpace,
	UNICODE_WB_Double_Quote,
	UNICODE_WB_Single_Quote,
	UNICODE_WB_MidNum,
	UNICODE_WB_MidNumLet,
	UNICODE_WB_Numeric,
	UNICODE_WB_MidLetter,
	UNICODE_WB_MidNum,
	UNICODE_WB_ALetter,
	UNICODE_WB_ExtendNumLet,
	UNICODE_WB_ALetter,
	UNICODE_WB_Newline,
	UNICODE_WB_ALetter,
	UNICODE_WB_Format,
	UNICODE_WB_ALetter,
	UNICODE_WB_MidLetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_MidNum,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_MidLetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_MidLetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_MidNum,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_ALetter,
	UNICODE_WB_MidLetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_MidNum,
	UNICODE_WB_Extend,
	UNICODE_WB_Format,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Numeric,
	UNICODE_WB_MidNum,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_MidNum,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_WSegSpace,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Format,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_WSegSpace,
	UNICODE_WB_WSegSpace,
	UNICODE_WB_Extend,
	UNICODE_WB_ZWJ,
	UNICODE_WB_Format,
	UNICODE_WB_MidNumLet,
	UNICODE_WB_MidNumLet,
	UNICODE_WB_MidLetter,
	UNICODE_WB_Newline,
	UNICODE_WB_Format,
	UNICODE_WB_ExtendNumLet,
	UNICODE_WB_ExtendNumLet,
	UNICODE_WB_MidNum,
	UNICODE_WB_ExtendNumLet,
	UNICODE_WB_WSegSpace,
	UNICODE_WB_Format,
	UNICODE_WB_Format,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_WSegSpace,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Katakana,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_Extend,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_Hebrew_Letter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_MidLetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ExtendNumLet,
	UNICODE_WB_ExtendNumLet,
	UNICODE_WB_MidNum,
	UNICODE_WB_MidNumLet,
	UNICODE_WB_MidNum,
	UNICODE_WB_MidLetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Format,
	UNICODE_WB_MidNumLet,
	UNICODE_WB_MidNum,
	UNICODE_WB_MidNumLet,
	UNICODE_WB_Numeric,
	UNICODE_WB_MidLetter,
	UNICODE_WB_MidNum,
	UNICODE_WB_ALetter,
	UNICODE_WB_ExtendNumLet,
	UNICODE_WB_ALetter,
	UNICODE_WB_Katakana,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Format,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Format,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_Katakana,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Format,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Format,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Extend,
	UNICODE_WB_ALetter,
	UNICODE_WB_Numeric,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_ALetter,
	UNICODE_WB_Regional_Indicator,
	UNICODE_WB_Extend,
	UNICODE_WB_Numeric,
	UNICODE_WB_Format,
	UNICODE_WB_Extend,
	UNICODE_WB_Extend};

static const size_t unicode_starting_indextab[]={
	0,
	1,
	2,
	3,
	4,
	5,
	6,
	7,
	8,
	9,
	10,
	11,
	12,
	13,
	14,
	15,
	16,
	17,
	18,
	19,
	20,
	21,
	22,
	23,
	24,
	25,
	26,
	27,
	28,
	29,
	30,
	31,
	32,
	33,
	36,
	44,
	45,
	46,
	48,
	49,
	50,
	51,
	160,
	161,
	162,
	163,
	164,
	165,
	166,
	167,
	168,
	169,
	170,
	171,
	172,
	173,
	174,
	175,
	176,
	177,
	178,
	179,
	180,
	181,
	182,
	183,
	184,
	185,
	186,
	187,
	188,
	189,
	190,
	191,
	192,
	193,
	194,
	195,
	196,
	197,
	198,
	199,
	200,
	201,
	202,
	203,
	204,
	205,
	206,
	207,
	208,
	209,
	210,
	211,
	212,
	213,
	214,
	215,
	251,
	252,
	253,
	254,
	255,
	256,
	257,
	258,
	259,
	260,
	261,
	262,
	263,
	264,
	265,
	266,
	267,
	268,
	269,
	270,
	271,
	272,
	273,
	274,
	275,
	276,
	277,
	278,
	279,
	280,
	281,
	282,
	283,
	284,
	285,
	286,
	287,
	288,
	289,
	290,
	291,
	292,
	293,
	303,
	304,
	305,
	306,
	307,
	308,
	309,
	310,
	311,
	312,
	313,
	314,
	315,
	316,
	317,
	318,
	319,
	320,
	321,
	322,
	323,
	324,
	325,
	326,
	353,
	360,
	361,
	362,
	363,
	365,
	366,
	367,
	431,
	432,
	433,
	444,
	460,
	463,
	465,
	466,
	468,
	469,
	470,
	471,
	474,
	479,
	480,
	481,
	482,
	484,
	485,
	487,
	488,
	489,
	494,
	497,
	499,
	507,
	3584,
	3585
};

static const char32_t unicode_starting_pagetab[]={
	0,
	23,
	24,
	26,
	39,
	42,
	59,
	82,
	96,
	115,
	147,
	184,
	219,
	254,
	282,
	290,
	305,
	321,
	322,
	336,
	343,
	344,
	345,
	351,
	363,
	374,
	379,
	387,
	400,
	418,
	420,
	421,
	440,
	461,
	475,
	476,
	480,
	496,
	497,
	506,
	510,
	511,
	512,
	513,
	514,
	515,
	516,
	518,
	519,
	530,
	535,
	554,
	567,
	584,
	594,
	595,
	596,
	597,
	598,
	599,
	600,
	601,
	602,
	603,
	604,
	605,
	606,
	607,
	608,
	609,
	610,
	611,
	612,
	613,
	614,
	615,
	616,
	617,
	618,
	619,
	620,
	621,
	622,
	623,
	624,
	625,
	626,
	627,
	628,
	629,
	630,
	631,
	632,
	633,
	634,
	635,
	636,
	637,
	640,
	653,
	654,
	658,
	670,
	687,
	694,
	696,
	699,
	707,
	711,
	722,
	723,
	729,
	739,
	743,
	757,
	761,
	764,
	771,
	776,
	784,
	800,
	819,
	833,
	865,
	876,
	881,
	890,
	892,
	897,
	917,
	930,
	932,
	941,
	959,
	961,
	971,
	972,
	973,
	974,
	975,
	977,
	978,
	979,
	980,
	981,
	982,
	983,
	989,
	990,
	991,
	992,
	993,
	994,
	995,
	996,
	997,
	998,
	999,
	1000,
	1001,
	1002,
	1003,
	1004,
	1005,
	1006,
	1007,
	1010,
	1011,
	1012,
	1019,
	1025,
	1027,
	1028,
	1038,
	1041,
	1042,
	1045,
	1051,
	1052,
	1054,
	1060,
	1061,
	1071,
	1081,
	1086,
	1095,
	1101,
	1103,
	1110,
	1115,
	1120,
	1123,
	1127,
	1131,
	1133,
	1137,
	1170,
	1174,
	1175,
	1176,
	1178
};

